@@ -1,6 +1,6 @@
 # -*- Mode: Python; python-indent-offset: 4 -*-
 #
-# Time-stamp: <2020-04-13 16:08:02 alex>
+# Time-stamp: <2021-03-04 16:47:20 alex>
 #
 # only for python v3
 
@@ -10,6 +10,7 @@ SOLIDserver management server access
 
 import logging
 import ipaddress
+import socket
 
 from json.decoder import JSONDecodeError
 
@@ -61,6 +62,18 @@ class SDS(ClassParams):
 
         self.sds_ip = ip_address
 
+    # ---------------------------
+    def set_server_name(self, fqdn):
+        """set the SOLIDserver FQDN for the connection"""
+        # check that the IP exists
+        try:
+            _ = socket.gethostbyname(fqdn)
+        except socket.gaierror as error:
+            raise SDSInitError(message="FQDN of the SDS: {}".
+                               format(error))
+
+        self.sds_ip = fqdn
+
     # ---------------------------
     def set_credentials(self, user=None, pwd=None):
         """add user and login to credentials of this session"""
@@ -107,7 +120,8 @@ class SDS(ClassParams):
         self.version = self.get_version()
 
         if self.version is None:   # pragma: no cover
-            raise SDSInitError(message="version of SOLIDserver not found")
+            self.version = "ukn"
+            # need to check if a simple call to a space api is working
 
     # ---------------------------
     def disconnect(self):
